"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const package_json_1 = require("gatsby/package.json");
const semver_1 = require("semver");
const debug_1 = __importDefault(require("../debug"));
let warnOnceForNoSupport;
let warnOnceToUpgradeGatsby;
const GATSBY_VERSION_MANIFEST_V2 = `4.3.0`;
const gatsbyVersion = package_json_1.version;
const gatsbyVersionIsPrerelease = (() => {
    try {
        return (0, semver_1.prerelease)(gatsbyVersion);
    }
    catch (error) {
        return null;
    }
})();
const shouldUpgradeGatsbyVersion = (() => {
    try {
        return (0, semver_1.lt)(gatsbyVersion, GATSBY_VERSION_MANIFEST_V2) && !gatsbyVersionIsPrerelease;
    }
    catch (error) {
        return true;
    }
})();
function createNodeManifest(actions, args, node, publishedId) {
    try {
        const { unstable_createNodeManifest } = actions;
        const { getNode } = args;
        const type = node.internal.type;
        const autogeneratedTypes = ['SanityFileAsset', 'SanityImageAsset'];
        const createNodeManifestIsSupported = typeof unstable_createNodeManifest === 'function';
        const nodeTypeNeedsManifest = autogeneratedTypes.includes(type) === false;
        const shouldCreateNodeManifest = createNodeManifestIsSupported && nodeTypeNeedsManifest;
        if (shouldCreateNodeManifest) {
            if (shouldUpgradeGatsbyVersion && !warnOnceToUpgradeGatsby) {
                console.warn(`Your site is doing more work than it needs to for Preview, upgrade to Gatsby ^${GATSBY_VERSION_MANIFEST_V2} for better performance`);
                warnOnceToUpgradeGatsby = true;
            }
            const updatedAt = new Date(node._updatedAt || Date.now());
            const nodeForManifest = getNode(node.id);
            const manifestId = `${publishedId}-${updatedAt.toISOString()}`;
            unstable_createNodeManifest({
                manifestId,
                node: nodeForManifest,
                updatedAtUTC: updatedAt.toUTCString(),
            });
        }
        else if (!createNodeManifestIsSupported && !warnOnceForNoSupport) {
            args.reporter.warn(`Sanity: Your version of Gatsby core doesn't support Content Sync (via the unstable_createNodeManifest action). Please upgrade to the latest version to use Content Sync in your site.`);
            warnOnceForNoSupport = true;
        }
    }
    catch (e) {
        let result = e.message;
        (0, debug_1.default)(`Cannot create node manifest`, result);
    }
}
exports.default = createNodeManifest;
//# sourceMappingURL=createNodeManifest.js.map